==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/authorization/entity/MapScopeEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapScopeEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapScopeEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getId();
        }
    },
    DISPLAY_NAME {
        public static final String FIELD_NAME = "DisplayName";
        public static final String FIELD_NAME_DASHED = "display-name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setDisplayName((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getDisplayName();
        }
    },
    ICON_URI {
        public static final String FIELD_NAME = "IconUri";
        public static final String FIELD_NAME_DASHED = "icon-uri";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getIconUri();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setIconUri((String) value);
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setName((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getName();
        }
    },
    RESOURCE_SERVER_ID {
        public static final String FIELD_NAME = "ResourceServerId";
        public static final String FIELD_NAME_DASHED = "resource-server-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setResourceServerId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getResourceServerId();
        }
    },
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapScopeEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapScopeEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapScopeEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setId((String) value);
        }
    },
    DISPLAY_NAME {
        public static final String FIELD_NAME = "DisplayName";
        public static final String FIELD_NAME_DASHED = "display-name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getDisplayName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setDisplayName((String) value);
        }
    },
    ICON_URI {
        public static final String FIELD_NAME = "IconUri";
        public static final String FIELD_NAME_DASHED = "icon-uri";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setIconUri((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getIconUri();
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setName((String) value);
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setRealmId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getRealmId();
        }
    },
    RESOURCE_SERVER_ID {
        public static final String FIELD_NAME = "ResourceServerId";
        public static final String FIELD_NAME_DASHED = "resource-server-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapScopeEntity e, T value) {
            e.setResourceServerId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapScopeEntity e) {
            return (String) e.getResourceServerId();
        }
    },
}
